[![wq.core](https://raw.github.com/wq/wq/master/images/256/wq.core.png)](https://wq.io/wq.core)

[wq.core](https://wq.io/wq.core) provides the core `wq` command line application for use by [wq.app](https://wq.io/wq.app) and other modules in the [wq framework](https://wq.io/).

[![Latest PyPI Release](https://img.shields.io/pypi/v/wq.core.svg)](https://pypi.org/project/wq.core)
[![Release Notes](https://img.shields.io/github/release/wq/wq.core.svg)](https://github.com/wq/wq.core/releases)
[![Documentation](https://img.shields.io/badge/Docs-1.2-blue.svg)](https://wq.io/wq.core)
[![License](https://img.shields.io/pypi/l/wq.core.svg)](https://wq.io/license)
[![GitHub Stars](https://img.shields.io/github/stars/wq/wq.core.svg)](https://github.com/wq/wq.core/stargazers)
[![GitHub Forks](https://img.shields.io/github/forks/wq/wq.core.svg)](https://github.com/wq/wq.core/network)
[![GitHub Issues](https://img.shields.io/github/issues/wq/wq.core.svg)](https://github.com/wq/wq.core/issues)

[![Travis Build Status](https://img.shields.io/travis/wq/wq.core/master.svg)](https://travis-ci.org/wq/wq.core)

## Getting Started

```bash
# Recommended: create virtual environment
# python3 -m venv venv
# . venv/bin/activate

# Install entire wq suite (recommended)
python3 -m pip install wq

# Install only wq.core
python3 -m pip install wq.core
```

## Command Line Reference

```bash
wq --help
```

See [the documentation](https://wq.io/docs/wq) for more information.
